.. Problem Solving with Algorithms and Data Structures documentation master file, created by
   sphinx-quickstart on Thu Oct 27 08:17:45 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==============================================================
Welcome to Problem Solving with Algorithms and Data Structures
==============================================================

By Brad Miller and David Ranum, Luther College


Introduction
::::::::::::

.. toctree::
   :maxdepth: 2

   Introduction/introduction.rst

Analysis
::::::::

.. toctree::
   :maxdepth: 2

   AlgorithmAnalysis/analysis.rst

Basic Data Structures
:::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   BasicDS/basic.rst
   BasicDS/stacks.rst
   BasicDS/queues.rst
   BasicDS/deques.rst
   BasicDS/linkedlists.rst
   BasicDS/basic_ex.rst

Recursion
:::::::::

.. toctree::
   :maxdepth: 2

   Recursion/recursionsimple.rst
   Recursion/graphical.rst
   Recursion/recursioncomplex.rst
   Recursion/recursionexercises.rst


Sorting and Searching
:::::::::::::::::::::

.. toctree::
   :maxdepth: 2
   
   SortSearch/searching.rst
   SortSearch/sorting.rst
   SortSearch/sortsearchexercises.rst

Trees and Tree Agorithms
::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   Trees/trees.rst
   Trees/implementation.rst
   Trees/bintreeapps.rst
   Trees/heap.rst
   Trees/bst.rst
   Trees/balanced.rst
   Trees/treeexercises.rst


Graphs and Graph Algorithms
:::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   Graphs/graphintro.rst
   Graphs/graphbfs.rst
   Graphs/graphdfs.rst
   Graphs/graphshortpath.rst
   Graphs/graphexercises.rst
   

Acknowledgements
::::::::::::::::
.. toctree::
    :maxdepth: 1

    copyright.rst
    prefaceinteractive.rst
    foreword.rst
    preface.rst
    preface2e.rst
    contrib.rst

Indices and tables
::::::::::::::::::

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

